#
# spec file for package python-django-polymorphic
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-django-polymorphic
Version:        3.1
%define twodotsversion 3.1.0
Release:        3.2
Summary:        Polymorphic inheritance for Django models
License:        BSD-3-Clause
URL:            https://github.com/jazzband/django-polymorphic
Source:         https://github.com/jazzband/django-polymorphic/archive/v%{version}.tar.gz#/django-polymorphic-%{version}.tar.gz
# PATCH-FIX-UPSTREAM gh#jazzband/django-polymorphic#63d291f8771847e716a37652f239e3966a3360e1
Patch0:         support-new-django.patch
# PATCH-FIX-OPENSUSE Skip two broken tests -- remove when upgrading to 4.0
Patch1:         skip-two-lookup-tests.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 2.1
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Django >= 2.1}
BuildRequires:  %{python_module dj-database-url}
# /SECTION
%python_subpackages

%description
Seamless polymorphic inheritance for Django models.

%prep
%autosetup -p1 -n django-polymorphic-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_exec runtests.py -v 2

%files %{python_files}
%doc README.rst docs/*.rst
%license LICENSE
%{python_sitelib}/polymorphic
%{python_sitelib}/django_polymorphic-%{twodotsversion}.dist-info

%changelog
* Wed Nov 13 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update URL.
- Switch to pyproject and autosetup macros.
- No more greedy globs in %%files.
- Add patch support-new-django.patch:
  * Support new Django assertion method name.
- Add patch skip-two-lookup-tests.patch:
  * Skip two tests that are currently broken
* Fri Jan  7 2022 John Vandenberg <jayvdb@gmail.com>
- Skip Tumbleweed Python 3.6 incompatible with Django 4
* Sun Dec 26 2021 John Vandenberg <jayvdb@gmail.com>
- Remove no longer needed Source runtests.py
- Added docs from source
- Update to v3.1.0
  * Added support for Django 4.0.
  * Fixed crash when the admin "add type" view has no choices; will
    show a permission denied.
  * Fixed missing locale folder in sdist.
  * Fixed missing QuerySet.bulk_create(.., ignore_conflicts=True)
    parameter support.
  * Fixed FilteredRelation support.
  * Fixed supporting class keyword arguments in model definitions
    for __init_subclass__().
  * Fixed including polymorphic.tests.migrations in the sdist.
  * Fixed non-polymorphic parent handling, which has no _base_objects
  * Fixed missing widgets support for modelform_factory().
  * Fixed has_changed handling for polymorphic_ctype_id due to
    implicit str to int conversions.
  * Fixed Q object handling when lists are used
    (e.g. in django-advanced-filters).
  * Fixed Django Admin support when using a script-prefix.
* Wed Sep  9 2020 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
- Update to v3.0.0
* Tue Mar 31 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v2.1.2
* Wed May 18 2016 Angelos Tzotsos <tzotsos@opensuse.org> - 0.5.6
- Initial spec file
